"""客户端游戏模块 — 导入即注册渲染器和处理器"""

from . import world_renderer  # noqa: F401
from . import world_handler   # noqa: F401
from . import wordle_renderer  # noqa: F401
from . import wordle_handler   # noqa: F401
from . import mahjong_renderer  # noqa: F401
from . import mahjong_handler   # noqa: F401
